%global with_bundled 1
%global with_debug 0

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global provider github
%global provider_tld com
%global project containers
%global repo buildah
# https://github.com/containers/buildah
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global git0 https://%{import_path}
%global commit0 df9247c59b2d44cb7b698fab124f2efe6a17032d
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})

# Used for comparing with latest upstream tag
# to decide whether to autobuild (non-rawhide only)
%global built_tag v1.37.4

Name: %{repo}
Version: 1.37.4
Release: %mkrel 1
Group: System/Configuration
Summary: A command line tool used for creating OCI Images
License: ASL 2.0
URL: https://%{name}.io
Source: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz

# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires: %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}
BuildRequires: git
BuildRequires: go-rpm-macros
BuildRequires: glib2-devel
BuildRequires: libseccomp-devel
BuildRequires: pkgconfig(gio-unix-2.0)
BuildRequires: glibc-static-devel
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: device-mapper-devel
BuildRequires: btrfs-devel
BuildRequires: libassuan-devel
BuildRequires: make
Requires: opencontainers-runc >= 1.0.0-17
#Requires: containers-common
#Recommends: container-selinux
Recommends: slirp4netns >= 0.3-0
Recommends: fuse-overlayfs

%description
The %{name} package provides a command line tool which can be used to
* create a working container from scratch
or
* create a working container from an image as a starting point
* mount/umount a working container's root file system for manipulation
* save container's root file system layer to create a new image
* delete a working container or an image

%package tests
Summary: Tests for %{name}
Requires: %{name} = %{version}-%{release}
Requires: bats
Requires: bzip2
Requires: podman
Requires: golang
Requires: jq
Requires: apache
Requires: openssl

%description tests
%{summary}

This package contains system tests for %{name}

%prep
%autosetup -Sgit -n %{name}-%{commit0}
sed -i 's/GOMD2MAN =/GOMD2MAN ?=/' docs/Makefile
sed -i '/docs install/d' Makefile

%build
mkdir _build
pushd _build
mkdir -p src/%{provider}.%{provider_tld}/%{project}
ln -s $(dirs +1 -l) src/%{import_path}
popd

mv vendor src

export GOPATH=$(pwd)/_build:$(pwd)
export BUILDTAGS='seccomp selinux'
export GO111MODULE=off
%gobuild -o bin/%{name} %{import_path}/cmd/%{name}
%gobuild -o bin/imgtype %{import_path}/tests/imgtype
GOMD2MAN=go-md2man %{__make} -C docs

%install
export GOPATH=$(pwd)/_build:$(pwd):%{gopath}
make DESTDIR=%{buildroot} PREFIX=%{_prefix} install install.completions
make DESTDIR=%{buildroot} PREFIX=%{_prefix} -C docs install

install -d -p %{buildroot}/%{_datadir}/%{name}/test/system
cp -pav tests/. %{buildroot}/%{_datadir}/%{name}/test/system
cp bin/imgtype %{buildroot}/%{_bindir}/%{name}-imgtype

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}

%files tests
%license LICENSE
%{_bindir}/%{name}-imgtype
%{_datadir}/%{name}/test


%changelog
* Fri Oct 11 2024 joequant <joequant> 1.37.4-1.mga10
+ Revision: 2104987
- update to 1.37.4

* Sun Aug 25 2024 neoclust <neoclust> 1.37.2-1.mga10
+ Revision: 2091272
- New version 1.37.2

* Sun Aug 04 2024 joequant <joequant> 1.37.0-1.mga10
+ Revision: 2083577
- update to 1.37.0

* Sun Mar 10 2024 joequant <joequant> 1.35.0-1.mga10
+ Revision: 2048924
- update to 1.35

* Tue Nov 07 2023 joequant <joequant> 1.31.4-1.mga10
+ Revision: 2004999
- update to 1.31.4

* Wed Jun 21 2023 joequant <joequant> 1.30.0-1.mga9
+ Revision: 1962724
- upgrade to 1.30.0 - address issue in 28885

* Sun Oct 23 2022 joequant <joequant> 1.28.0-1.mga9
+ Revision: 1898770
- update to 1.28.0

* Sun Oct 02 2022 joequant <joequant> 1.27.2-1.mga9
+ Revision: 1893761
- update to 1.27.2

* Fri Aug 19 2022 joequant <joequant> 1.27.0-1.mga9
+ Revision: 1878611
- update to 1.27.0

* Sun Jul 10 2022 joequant <joequant> 1.26.2-1.mga9
+ Revision: 1868219
- update to 1.26.2

* Mon Apr 04 2022 umeabot <umeabot> 1.23.1-2.mga9
+ Revision: 1843773
- Mageia 9 Mass Rebuild

* Tue Oct 05 2021 joequant <joequant> 1.23.1-1.mga9
+ Revision: 1749549
- update to 1.23.1

* Sat Sep 18 2021 joequant <joequant> 1.23.0-1.mga9
+ Revision: 1745673
- update to 1.23.0

* Sun Jul 25 2021 joequant <joequant> 1.21.4-1.mga9
+ Revision: 1737645
- update to 1.21.4 - fix #28885

* Sun Jul 04 2021 joequant <joequant> 1.21.2-1.mga9
+ Revision: 1734674
- update to 1.21.2

* Sat Dec 05 2020 joequant <joequant> 1.18.0-1.mga8
+ Revision: 1652976
- update to 1.18.0

* Tue Oct 27 2020 joequant <joequant> 1.16.5-1.mga8
+ Revision: 1639754
- update to 1.16.5

* Fri Aug 07 2020 joequant <joequant> 1.15.1-1.mga8
+ Revision: 1611679
- update 1.15.1

* Mon Jul 13 2020 joequant <joequant> 1.15.0-1.mga8
+ Revision: 1605786
- update to 1.15.0

* Thu Jun 11 2020 joequant <joequant> 1.14.9-1.mga8
+ Revision: 1592286
- update to 1.14.9

* Sun Apr 26 2020 joequant <joequant> 1.14.8-1.mga8
+ Revision: 1572360
- update to 1.14.8

* Sun Apr 05 2020 joequant <joequant> 1.14.6-1.mga8
+ Revision: 1564890
- update to 1.14.6

* Sun Apr 05 2020 joequant <joequant> 1.12.0-1.mga8
+ Revision: 1564880
- change ostree devel
- add group and golang macros
- imported package buildah

